@@ -34,11 +34,10 @@ def clear_line():
     print ("\033[A\033[A")
 
 def test():
-    print('2+2=[green]4[/] and 3+3=[bg red]6[/]')
-    print('[yellow]Warning. [red][underline]Error[/] [green]Success[/]')
+    print('2+2=[green]4[/] and 3+3=[bg red]6')
+    print('[yellow]Warning. [red][underline]Error[/] [green]Success')
     print('[bg blue][yellow]Colorful[/] Back to normal')
 
     print('Status: TBD')
     move_up()
-    print('[bold]Status: [green]Complete[/]')
-
+    print('[bold]Status: [green]Complete')
